Some additional __doc__ comments (with some ideas for future plans) and removal
authorTodd Larsen <tlarsen@google.com>
Wed, 20 Aug 2008 00:10:59 +0000
changeset 88 9a8180f0941a
parent 87 7ccc026f5793
child 89 5decd7730e02
Some additional __doc__ comments (with some ideas for future plans) and removal of some unnecessary imports.
app/soc/views/site/home.py
--- a/app/soc/views/site/home.py	Wed Aug 20 00:08:31 2008 +0000
+++ b/app/soc/views/site/home.py	Wed Aug 20 00:10:59 2008 +0000
@@ -14,7 +14,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Melange home page
+"""Site-wide Melange home page views.
+
+public: how the general public sees the site home page of a Melange
+  site
+  
+There may (eventually) be different views of the site home page for
+logged-in Users (such as a debug() view for logged-in Developers). 
 """
 
 __authors__ = [
@@ -23,12 +29,11 @@
 
 
 from google.appengine.api import users
-from django import http
-from django import shortcuts
 from soc.views.helpers import response_helpers
 
+
 def public(request, template='soc/site/home/public.html'):
-  """Home site view of Melange.
+  """How the "general public" sees the Melange site home page.
 
   Args:
     request: the standard django request object.